@@ -10,7 +10,10 @@ extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx']
 source_suffix = '.rst'
 master_doc = 'index'
 project = u'xlrd'
-copyright = '2005-%s Stephen John Machin, Lingfo Pty Ltd' % datetime.datetime.now().year
+copyright = (
+    '2005-2019 Stephen John Machin, Lingfo Pty Ltd. '
+    '2019-%s Chris Withers'
+) % datetime.datetime.now().year
 version = release = __VERSION__
 exclude_patterns = ['_build']
 pygments_style = 'sphinx'
